==> eam-wshub-proxyclient-11.4-7-sources.jar: net/datastream/schemas/mp_fields/EXTRACHARGEDISCOUNTID_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Classe Java pour EXTRACHARGEDISCOUNTID_Type complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType name="EXTRACHARGEDISCOUNTID_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element name="CHARGEDISCOUNTCODE" type="{http://schemas.datastream.net/MP_fields}CODE8_Type"/>
 *         &lt;choice>
 *           &lt;element ref="{http://schemas.datastream.net/MP_fields}PURCHASEORDERLINEID"/>
 *           &lt;element ref="{http://schemas.datastream.net/MP_fields}INVOICEVOUCHERLINEID"/>
 *         &lt;/choice>
 *         &lt;element name="INVOICEORDER" type="{http://schemas.datastream.net/MP_fields}FLAG_Type"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "EXTRACHARGEDISCOUNTID_Type", propOrder = {
    "chargediscountcode",
    "purchaseorderlineid",
    "invoicevoucherlineid",
    "invoiceorder"
})
public class EXTRACHARGEDISCOUNTID_Type {

    @XmlElement(name = "CHARGEDISCOUNTCODE", required = true)
    protected String chargediscountcode;
    @XmlElement(name = "PURCHASEORDERLINEID")
    protected PURCHASEORDERLINEID_Type purchaseorderlineid;
    @XmlElement(name = "INVOICEVOUCHERLINEID")
    protected INVOICEVOUCHERLINEID_Type invoicevoucherlineid;
    @XmlElement(name = "INVOICEORDER", required = true)
    protected String invoiceorder;

    /**
     * Obtient la valeur de la propriété chargediscountcode.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getCHARGEDISCOUNTCODE() {
        return chargediscountcode;
    }

    /**
     * Définit la valeur de la propriété chargediscountcode.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setCHARGEDISCOUNTCODE(String value) {
        this.chargediscountcode = value;
    }

    /**
     * Obtient la valeur de la propriété purchaseorderlineid.
     * 
     * @return
     *     possible object is
     *     {@link PURCHASEORDERLINEID_Type }
     *     
     */
    public PURCHASEORDERLINEID_Type getPURCHASEORDERLINEID() {
        return purchaseorderlineid;
    }

    /**
     * Définit la valeur de la propriété purchaseorderlineid.
     * 
     * @param value
     *     allowed object is
     *     {@link PURCHASEORDERLINEID_Type }
     *     
     */
    public void setPURCHASEORDERLINEID(PURCHASEORDERLINEID_Type value) {
        this.purchaseorderlineid = value;
    }

    /**
     * Obtient la valeur de la propriété invoicevoucherlineid.
     * 
     * @return
     *     possible object is
     *     {@link INVOICEVOUCHERLINEID_Type }
     *     
     */
    public INVOICEVOUCHERLINEID_Type getINVOICEVOUCHERLINEID() {
        return invoicevoucherlineid;
    }

    /**
     * Définit la valeur de la propriété invoicevoucherlineid.
     * 
     * @param value
     *     allowed object is
     *     {@link INVOICEVOUCHERLINEID_Type }
     *     
     */
    public void setINVOICEVOUCHERLINEID(INVOICEVOUCHERLINEID_Type value) {
        this.invoicevoucherlineid = value;
    }

    /**
     * Obtient la valeur de la propriété invoiceorder.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getINVOICEORDER() {
        return invoiceorder;
    }

    /**
     * Définit la valeur de la propriété invoiceorder.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setINVOICEORDER(String value) {
        this.invoiceorder = value;
    }

}

==> eam-wshub-proxyclient-12.0-sources.jar: net/datastream/schemas/mp_fields/EXTRACHARGEDISCOUNTID_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for EXTRACHARGEDISCOUNTID_Type complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="EXTRACHARGEDISCOUNTID_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element name="CHARGEDISCOUNTCODE" type="{http://schemas.datastream.net/MP_fields}CODE8_Type"/>
 *         &lt;choice>
 *           &lt;element ref="{http://schemas.datastream.net/MP_fields}PURCHASEORDERLINEID"/>
 *           &lt;element ref="{http://schemas.datastream.net/MP_fields}INVOICEVOUCHERLINEID"/>
 *         &lt;/choice>
 *         &lt;element name="INVOICEORDER" type="{http://schemas.datastream.net/MP_fields}FLAG_Type"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "EXTRACHARGEDISCOUNTID_Type", propOrder = {
    "chargediscountcode",
    "purchaseorderlineid",
    "invoicevoucherlineid",
    "invoiceorder"
})
public class EXTRACHARGEDISCOUNTID_Type {

    @XmlElement(name = "CHARGEDISCOUNTCODE", required = true)
    protected String chargediscountcode;
    @XmlElement(name = "PURCHASEORDERLINEID")
    protected PURCHASEORDERLINEID_Type purchaseorderlineid;
    @XmlElement(name = "INVOICEVOUCHERLINEID")
    protected INVOICEVOUCHERLINEID_Type invoicevoucherlineid;
    @XmlElement(name = "INVOICEORDER", required = true)
    protected String invoiceorder;

    /**
     * Gets the value of the chargediscountcode property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getCHARGEDISCOUNTCODE() {
        return chargediscountcode;
    }

    /**
     * Sets the value of the chargediscountcode property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setCHARGEDISCOUNTCODE(String value) {
        this.chargediscountcode = value;
    }

    /**
     * Gets the value of the purchaseorderlineid property.
     * 
     * @return
     *     possible object is
     *     {@link PURCHASEORDERLINEID_Type }
     *     
     */
    public PURCHASEORDERLINEID_Type getPURCHASEORDERLINEID() {
        return purchaseorderlineid;
    }

    /**
     * Sets the value of the purchaseorderlineid property.
     * 
     * @param value
     *     allowed object is
     *     {@link PURCHASEORDERLINEID_Type }
     *     
     */
    public void setPURCHASEORDERLINEID(PURCHASEORDERLINEID_Type value) {
        this.purchaseorderlineid = value;
    }

    /**
     * Gets the value of the invoicevoucherlineid property.
     * 
     * @return
     *     possible object is
     *     {@link INVOICEVOUCHERLINEID_Type }
     *     
     */
    public INVOICEVOUCHERLINEID_Type getINVOICEVOUCHERLINEID() {
        return invoicevoucherlineid;
    }

    /**
     * Sets the value of the invoicevoucherlineid property.
     * 
     * @param value
     *     allowed object is
     *     {@link INVOICEVOUCHERLINEID_Type }
     *     
     */
    public void setINVOICEVOUCHERLINEID(INVOICEVOUCHERLINEID_Type value) {
        this.invoicevoucherlineid = value;
    }

    /**
     * Gets the value of the invoiceorder property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getINVOICEORDER() {
        return invoiceorder;
    }

    /**
     * Sets the value of the invoiceorder property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setINVOICEORDER(String value) {
        this.invoiceorder = value;
    }

}
